"""Configuration Index - Auto-generated

This file is automatically generated by scripts/configs/generate_all_configs.py
Do not edit manually.
"""

AVAILABLE_CONFIGS = [
  {
    "filename": "ascii-cxtft.json",
    "name": "ascii-cxtft",
    "description": "Basic Latin alphabet, 8 consonants, 5 vowels, 10 syllables, max 1 consecutive",
    "consonants_count": 8,
    "vowels_count": 5,
    "address_length": 10,
    "max_consecutive": 1,
    "identifier": "",
    "auto_generated": true
  },
  {
    "filename": "ascii-glqvb.json",
    "name": "ascii-glqvb",
    "description": "Basic Latin alphabet, 12 consonants, 4 vowels, 9 syllables, max 1 consecutive",
    "consonants_count": 12,
    "vowels_count": 4,
    "address_length": 9,
    "max_consecutive": 1,
    "identifier": "",
    "auto_generated": true
  },
  {
    "filename": "ascii-sfnmh.json",
    "name": "ascii-sfnmh",
    "description": "Basic Latin alphabet, 15 consonants, 5 vowels, 8 syllables, max 1 consecutive",
    "consonants_count": 15,
    "vowels_count": 5,
    "address_length": 8,
    "max_consecutive": 1,
    "identifier": "",
    "auto_generated": true
  },
  {
    "filename": "ascii-gteup.json",
    "name": "ascii-gteup",
    "description": "Basic Latin alphabet, 14 consonants, 4 vowels, 9 syllables, max 1 consecutive",
    "consonants_count": 14,
    "vowels_count": 4,
    "address_length": 9,
    "max_consecutive": 1,
    "identifier": "",
    "auto_generated": true
  },
  {
    "filename": "ascii-bowoat.json",
    "name": "ascii-bowoat",
    "description": "Basic Latin alphabet, 12 consonants, 5 vowels, 9 syllables, max 1 consecutive",
    "consonants_count": 12,
    "vowels_count": 5,
    "address_length": 9,
    "max_consecutive": 1,
    "identifier": "",
    "auto_generated": true
  },
  {
    "filename": "ascii-etmhjj.json",
    "name": "ascii-etmhjj",
    "description": "Basic Latin alphabet, 16 consonants, 5 vowels, 8 syllables, max 1 consecutive",
    "consonants_count": 16,
    "vowels_count": 5,
    "address_length": 8,
    "max_consecutive": 1,
    "identifier": "",
    "auto_generated": true
  },
  {
    "filename": "ascii-bwihf.json",
    "name": "ascii-bwihf",
    "description": "Basic Latin alphabet, 9 consonants, 4 vowels, 10 syllables, max 1 consecutive",
    "consonants_count": 9,
    "vowels_count": 4,
    "address_length": 10,
    "max_consecutive": 1,
    "identifier": "",
    "auto_generated": true
  },
  {
    "filename": "ascii-fqwfmd.json",
    "name": "ascii-fqwfmd",
    "description": "Basic Latin alphabet, 21 consonants, 5 vowels, 8 syllables, max 1 consecutive",
    "consonants_count": 21,
    "vowels_count": 5,
    "address_length": 8,
    "max_consecutive": 1,
    "identifier": "",
    "auto_generated": true
  }
]

def get_config_info(config_name: str):
    """Get information about a configuration."""
    for config in AVAILABLE_CONFIGS:
        if config['name'] == config_name or config['filename'] == config_name:
            return config
    return None

def list_configs():
    """List all available configuration names."""
    return [config['name'] for config in AVAILABLE_CONFIGS]

def list_config_files():
    """List all configuration filenames."""
    return [config['filename'] for config in AVAILABLE_CONFIGS]
